==> fasthelp-1.0.13.tar.gz: fasthelp-1.0.13/README.md <==
# FastHelp

A fast, useful helper in Python. It just makes things much faster.

> I love FastHelp! It's really useful, You see
> -- The Founder of JVSC, leading dev of FastHelp

## Installation

You can install fasthelp using pip:

`pip install fasthelp`

## Dependencies

- NumPy >= 1.26
- Pandas >= 2.2

## Usage

`import fasthelp as fh`
fh is the common alias for FastHelp

### Changelog (Since 1.0.12)
- 1.0.13: Added `CHelper`, `JavaHelper`, `JSHelper`, `RHelper`, `FolderHelper` and `IDEHelper`
- 1.0.12: Insider Release. Bug fixes

## Version
FastHelp 1.0.13

## License
This project is licensed under the MIT License:


MIT License

Copyright (c) 2024 ZIYAN ZHOU

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> fasthelp-1.0.14.tar.gz: fasthelp-1.0.14/README.md <==
README.md File version: 1.3.29.6

# FastHelp

A fast, useful helper in Python. It just makes things much faster.

> I love FastHelp! It's really useful, You see.
> -- The Founder of JVSC, leading dev of FastHelp

## Installation

You can install fasthelp using pip:
`pip install fasthelp`

## Dependencies

- NumPy >= 1.26
- Pandas >= 2.2

## A sneak peak at the source code:
```py
import pandas as pd
import numpy as np
import pprint
import subprocess
import os
import warnings
```

## Usage

`import fasthelp as fh`
PS: `fh` is the common alias for FastHelp

## Changelog (Since 1.0.12)
- 1.0.14: More Bugfix. Removed some bad functions. Enhanced function performance. Minor documentation bugfix.
- 1.0.13: Added `CHelper`, `JavaHelper`, `JSHelper`, `RHelper`, `FolderHelper` and `IDEHelper`. Minimal Bugfixes.
- 1.0.12: Insider Release. Bug fixes.

## Version
FastHelp 1.0.14

## License
This project is licensed under the MIT License:


MIT License

Copyright (c) 2024 ZIYAN ZHOU

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
